import matplotlib.pyplot as plt#graphique
import pandas as pd#lecture du fichier csv
import matplotlib.dates as mdates
from pandas.plotting import register_matplotlib_converters
register_matplotlib_converters()
import matplotlib.ticker as tick#mise en forme des étiquettes de graduations

#Extraction des données depuis le fichier .csv :
soleil=pd.read_csv('EphemSoleil2022.csv',
sep=';', #séparateur des colonnes
usecols=[1, 4], #seules colonnes utiles,  ici
names=['date', 'midi'], #renomme les deux colonnes
parse_dates=['date'], #reconnaît les données de cette colonne comme des dates
skiprows=1, #supprime la ligne 1 (noms de colonnes d'origine)
)
#Extraction des listes de données pour les graphes :
soleil=soleil.set_index('date')#indexation du tableau de valeurs sur les dates
dates=soleil.index

midi=soleil['midi']

EDT=(midi-12)*60#calcul de l'équation du temps

plt.rcParams["font.family"] = "Ubuntu"#ou autre police installée
plt.rcParams["font.size"] = 9

def HHmm(heure, lever):#écrit en base 60
    H=int(heure)
    min=round((heure-H)*60)
    if min<10:
        min="0"+str(min)
    return str(H)+'h'+str(min)[:]

def mmss(min, EDT):#écrit en base 60    
#    sec=round((M-int(M))*60, 2)
    min=round(min)
    return str(min)+' min'#+str(sec)

#Paramètres du graphique :
fig=plt.figure(figsize=(7, 8), tight_layout=True)

locator1 = mdates.AutoDateLocator(minticks=11, maxticks=12, interval_multiples=True)
formatter = mdates.ConciseDateFormatter(locator1)

#Graphe 1---------------------------------------------------
ax1=plt.subplot(211)
ax1.set_title("Heure de passage du Soleil au méridien (midi moyen)")
ax1.grid()

ax1.plot(dates, midi, c='slateblue')
ax1.xaxis.set_major_locator(locator1)
ax1.xaxis.set_major_formatter(formatter)
ax1.set_xlim('2022-01-01', '2022-12-31')
ax1.yaxis.set_major_formatter(tick.FuncFormatter(HHmm))

#Graphe 2---------------------------------------------------
ax2=plt.subplot(212)
ax2.set_title("Équation du temps")
ax2.grid()

ax2.plot(dates, EDT, c='firebrick')
ax2.xaxis.set_major_locator(locator1)
ax2.xaxis.set_major_formatter(formatter)
ax2.set_xlim('2022-01-01', '2022-12-31')
ax2.yaxis.set_major_formatter(tick.FuncFormatter(mmss))

#fig.savefig("EquationDuTemps.png", dpi=200)
#fig.savefig("EquationDuTemps.pdf")
plt.show()
